function pdeDiff
%   Addaptierte Lsung der pdex1 aus MATLAB
%	Lsung des 2. Fickschen Gesetztes mit inhomogenen Randbedingungen
%
%   [1] .*   D_ [u] =  D_ [   Du/Dx   ] +      [0]
%               Dt        Dx
%    ----         ---       -------------    -------------
%     c            u        f(x,t,u,Du/Dx)   s(x,t,u,Du/Dx)
%
global Dab; global Cein;global k;global alpha; global ymax;
m = 0;
Cein = 0.545572934; %Startkonzentration in mol/L
Dab = 4.00406E-05; %Diffusionskoeffizient von 1-Hexen in Isohexan in cm^2/s (Wilke-Chang-Gl.)
alpha = 68.61395435; % Phasenaustauschflche zu organischem Volumen in 1/m
k = 6.53E-06*alpha; %Effektive Reaktionsgeschwindigkeitskonstante in 1/s
ymax = 1.46; %Hhe der organischen Isohexan/1-Hexen Mischung bei 5ml in cm

x = linspace(0,ymax,150);
t = linspace(0,100000,1000);

x2 = [0.809 0.517 0.226]; %Spritzenposition in cm
t2 = [3600 9000 14400 18000 79200]; %GC-Messzeitpunkte in s

sol = pdepe(m,@pdeDiffpde,@pdeDiffic,@pdeDiffbc,x,t);
u = sol(:,:,1)./Cein;

%Messwerte
c36 = [0.473213487	0.444278568	0.295593048]./Cein;
c90 = [0.395318709	0.355796864	0.206496457]./Cein;
c144 = [0.324964397	0.274913428	0.136348314]./Cein;
c180 = [0.273317362	0.214112921	0.106677252]./Cein;
c792 = [0.070935016	0.063611732	0.041758917]./Cein;

hold on
%figure;
plot(x,u(36,:),x,u(90,:),x,u(144,:),x,u(180,:),x,u(792,:));
plot(x2,c36,'rs','LineWidth',2,'MarkerEdgeColor','k','MarkerFaceColor','g','MarkerSize',10)
plot(x2,c90,'rs','LineWidth',2,'MarkerEdgeColor','k','MarkerFaceColor','b','MarkerSize',10)
plot(x2,c144,'rs','LineWidth',2,'MarkerEdgeColor','k','MarkerFaceColor','y','MarkerSize',10)
plot(x2,c180,'rs','LineWidth',2,'MarkerEdgeColor','k','MarkerFaceColor','m','MarkerSize',10)
plot(x2,c792,'rs','LineWidth',2,'MarkerEdgeColor','k','MarkerFaceColor','r','MarkerSize',10)

Parx= [u(36,81) u(36,52) u(36,23) u(90,81) u(90,52) u(90,21) u(144,81) u(144,52) u(144,23) u(180,81) u(180,52) u(180,23) u(792,81) u(792,52) u(792,23)];            
Pary= [c36 c90 c144 c180 c792];

pp = [Pary; Parx;];

xls = [x./ymax; u(36,:); u(90,:); u(144,:); u(180,:); u(792,:)];

xlswrite('ausgabe2.xlsx',xls');
xlswrite('ausgabe.xlsx',pp');

% ------------------------------------------------------

function [c,f,s] = pdeDiffpde(x,t,u,DuDx)
global Dab 
c = 1;
f = Dab*DuDx;
s = 0;

% ------------------------------------------------------
% Anfangsbedingung
function u0 = pdeDiffic(x)
global Cein
u0 = Cein;    
% -------------------------------------------------------

%Randbedingungen
function [pl,ql,pr,qr] = pdeDiffbc(xl,ul,xr,ur,t)
global k;
pr = 0;
qr = 1;
pl = -ul*k;
ql = 1;


